public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r13-4580] Rename SUBTARGET_CC1_SPEC to OS_CC1_SPEC
@ 2022-12-09  7:02 Sebastian Huber
  0 siblings, 0 replies; only message in thread
From: Sebastian Huber @ 2022-12-09  7:02 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:3e4b8dc477c12f303171ec7f0394c97494095545

commit r13-4580-g3e4b8dc477c12f303171ec7f0394c97494095545
Author: Sebastian Huber <sebastian.huber@embedded-brains.de>
Date:   Fri Dec 9 07:55:52 2022 +0100

    Rename SUBTARGET_CC1_SPEC to OS_CC1_SPEC
    
    This change resolves a naming conflict introduced by the recently added
    SUBTARGET_CC1_SPEC to gcc.cc.  Some targets (mips and loongarch) aready used
    a SUBTARGET_CC1_SPEC define.  Rename the define used by gcc.cc to OS_CC1_SPEC.
    
    gcc/ChangeLog:
    
            * config/rtems.h (SUBTARGET_CC1_SPEC): Rename to...
            (OS_CC1_SPEC): ...this.
            * gcc.cc (SUBTARGET_CC1_SPEC): Rename to...
            (OS_CC1_SPEC): ...this.

Diff:
---
 gcc/config/rtems.h |  4 ++--
 gcc/gcc.cc         | 10 +++++-----
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/gcc/config/rtems.h b/gcc/config/rtems.h
index 4742b1f3722..7ee68af243f 100644
--- a/gcc/config/rtems.h
+++ b/gcc/config/rtems.h
@@ -58,5 +58,5 @@
 #define STDINT_LONG32 (INT_TYPE_SIZE != 32 && LONG_TYPE_SIZE == 32)
 
 /* Default to local-exec TLS model.  */
-#undef SUBTARGET_CC1_SPEC
-#define SUBTARGET_CC1_SPEC " %{!ftls-model=*:-ftls-model=local-exec}"
+#undef OS_CC1_SPEC
+#define OS_CC1_SPEC " %{!ftls-model=*:-ftls-model=local-exec}"
diff --git a/gcc/gcc.cc b/gcc/gcc.cc
index 2278e2b6bb1..2568d541196 100644
--- a/gcc/gcc.cc
+++ b/gcc/gcc.cc
@@ -706,11 +706,11 @@ proper position among the other output files.  */
 #define CPP_SPEC ""
 #endif
 
-/* Subtargets can define SUBTARGET_CC1_SPEC to provide extra args to cc1 and
-   cc1plus or extra switch-translations.  The SUBTARGET_CC1_SPEC is appended
+/* Operating systems can define OS_CC1_SPEC to provide extra args to cc1 and
+   cc1plus or extra switch-translations.  The OS_CC1_SPEC is appended
    to CC1_SPEC in the initialization of cc1_spec.  */
-#ifndef SUBTARGET_CC1_SPEC
-#define SUBTARGET_CC1_SPEC ""
+#ifndef OS_CC1_SPEC
+#define OS_CC1_SPEC ""
 #endif
 
 /* config.h can define CC1_SPEC to provide extra args to cc1 and cc1plus
@@ -1181,7 +1181,7 @@ proper position among the other output files.  */
 static const char *asm_debug = ASM_DEBUG_SPEC;
 static const char *asm_debug_option = ASM_DEBUG_OPTION_SPEC;
 static const char *cpp_spec = CPP_SPEC;
-static const char *cc1_spec = CC1_SPEC SUBTARGET_CC1_SPEC;
+static const char *cc1_spec = CC1_SPEC OS_CC1_SPEC;
 static const char *cc1plus_spec = CC1PLUS_SPEC;
 static const char *link_gcc_c_sequence_spec = LINK_GCC_C_SEQUENCE_SPEC;
 static const char *link_ssp_spec = LINK_SSP_SPEC;

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-12-09  7:02 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-12-09  7:02 [gcc r13-4580] Rename SUBTARGET_CC1_SPEC to OS_CC1_SPEC Sebastian Huber

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).